==> applet-service-1.0.2-20190124.082856-16-sources.jar: com/bizvane/appletservice/models/bo/AppletCardLevelPrivLegeBo.java <==
package com.bizvane.appletservice.models.bo;

import com.bizvane.appletservice.models.po.AppletVipPrivilegePO;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.List;

public class AppletCardLevelPrivLegeBo implements Serializable {
    private static final long serialVersionUID = -7781874198944293766L;
    @ApiModelProperty(
            value = "微信头像",
            name = "wxHeadPortraits",
            example = "微信头像"
    )
    private String wxHeadPortraits;
    @ApiModelProperty(
            value = "微信昵称",
            name = "wxNick",
            example = "微信昵称"
    )
    private String wxNick;
    @ApiModelProperty(
            value = "会员可用积分",
            name = "countIntegral",
            example = "会员可用积分"
    )
    private String countIntegral;
    @ApiModelProperty(
            value = "会员卡等级名",
            name = "levelName",
            example = "会员卡等级名"
    )
    private String levelName;
    @ApiModelProperty(
            value = "会员等级id",
            name = "levelId",
            example = "会员等级id"
    )
    private Long levelId;
    @ApiModelProperty(
            value = "会员卡条形码",
            name = "barCode",
            example = "会员卡条形码"
    )
    private String barCode;
    @ApiModelProperty(
            value = "线上卡号",
            name = "cardNo",
            example = "线上卡号"
    )
    private String cardNo;
    @ApiModelProperty(
            value = "线下卡号",
            name = "offlineCardNo",
            example = "线下卡号"
    )
    private String offlineCardNo;
    @ApiModelProperty(
            value = "会员卡折扣",
            name = "memberDiscount",
            example = "会员卡折扣"
    )
    private String memberDiscount;
    @ApiModelProperty(
            value = "会员卡折上折",
            name = "additionalDiscount",
            example = "会员卡折上折"
    )

//累计总积分
    private String additionalDiscount;

    //会员卡样式
    private String cardStyle;
    private String instructions;
    private Boolean isImg;
    private List<AppletVipPrivilegePO> appletVipPrivilegePOList;
    private Integer discountMethod;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getWxHeadPortraits() {
        return wxHeadPortraits;
    }

    public void setWxHeadPortraits(String wxHeadPortraits) {
        this.wxHeadPortraits = wxHeadPortraits;
    }

    public String getWxNick() {
        return wxNick;
    }

    public void setWxNick(String wxNick) {
        this.wxNick = wxNick;
    }

    public String getCountIntegral() {
        return countIntegral;
    }

    public void setCountIntegral(String countIntegral) {
        this.countIntegral = countIntegral;
    }

    public String getLevelName() {
        return levelName;
    }

    public void setLevelName(String levelName) {
        this.levelName = levelName;
    }

    public Long getLevelId() {
        return levelId;
    }

    public void setLevelId(Long levelId) {
        this.levelId = levelId;
    }

    public String getBarCode() {
        return barCode;
    }

    public void setBarCode(String barCode) {
        this.barCode = barCode;
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public String getMemberDiscount() {
        return memberDiscount;
    }

    public void setMemberDiscount(String memberDiscount) {
        this.memberDiscount = memberDiscount;
    }

    public String getAdditionalDiscount() {
        return additionalDiscount;
    }

    public void setAdditionalDiscount(String additionalDiscount) {
        this.additionalDiscount = additionalDiscount;
    }

    public String getCardStyle() {
        return cardStyle;
    }

    public void setCardStyle(String cardStyle) {
        this.cardStyle = cardStyle;
    }

    public List<AppletVipPrivilegePO> getAppletVipPrivilegePOList() {
        return appletVipPrivilegePOList;
    }

    public void setAppletVipPrivilegePOList(List<AppletVipPrivilegePO> appletVipPrivilegePOList) {
        this.appletVipPrivilegePOList = appletVipPrivilegePOList;
    }

    public String getInstructions() {
        return instructions;
    }

    public void setInstructions(String instructions) {
        this.instructions = instructions;
    }

    public Boolean getImg() {
        return isImg;
    }

    public void setImg(Boolean img) {
        isImg = img;
    }

    public Integer getDiscountMethod() {
        return discountMethod;
    }

    public void setDiscountMethod(Integer discountMethod) {
        this.discountMethod = discountMethod;
    }
}

==> applet-service-2.0.6-20220324.104419-1-sources.jar: com/bizvane/appletservice/models/bo/AppletCardLevelPrivLegeBo.java <==
package com.bizvane.appletservice.models.bo;

import com.bizvane.appletservice.models.po.AppletVipPrivilegePO;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.List;

public class AppletCardLevelPrivLegeBo implements Serializable {
    private static final long serialVersionUID = -7781874198944293766L;
    @ApiModelProperty(
            value = "微信头像",
            name = "wxHeadPortraits",
            example = "微信头像"
    )
    private String wxHeadPortraits;
    @ApiModelProperty(
            value = "微信昵称",
            name = "wxNick",
            example = "微信昵称"
    )
    private String wxNick;
    @ApiModelProperty(
            value = "会员可用积分",
            name = "countIntegral",
            example = "会员可用积分"
    )
    private String countIntegral;
    @ApiModelProperty(
            value = "会员卡等级名",
            name = "levelName",
            example = "会员卡等级名"
    )
    private String levelName;
    @ApiModelProperty(
            value = "会员等级id",
            name = "levelId",
            example = "会员等级id"
    )
    private Long levelId;
    @ApiModelProperty(
            value = "会员卡条形码",
            name = "barCode",
            example = "会员卡条形码"
    )
    private String barCode;
    @ApiModelProperty(
            value = "线上卡号",
            name = "cardNo",
            example = "线上卡号"
    )
    private String cardNo;
    @ApiModelProperty(
            value = "线下卡号",
            name = "offlineCardNo",
            example = "线下卡号"
    )
    private String offlineCardNo;
    @ApiModelProperty(
            value = "会员卡折扣",
            name = "memberDiscount",
            example = "会员卡折扣"
    )
    private String memberDiscount;
    @ApiModelProperty(
            value = "会员卡折上折",
            name = "additionalDiscount",
            example = "会员卡折上折"
    )

//累计总积分
    private String additionalDiscount;

    //会员卡样式
    private String cardStyle;
    private String instructions;
    private Boolean isImg;
    private List<AppletVipPrivilegePO> appletVipPrivilegePOList;
    private Integer discountMethod;

    @ApiModelProperty(value = "会员累计消费金额",name = "mbrConsumeMoney",example = "会员消费金额")
    private BigDecimal mbrConsumeAllMoney;

    public static long getSerialVersionUID() {
        return serialVersionUID;
    }

    public String getWxHeadPortraits() {
        return wxHeadPortraits;
    }

    public void setWxHeadPortraits(String wxHeadPortraits) {
        this.wxHeadPortraits = wxHeadPortraits;
    }

    public String getWxNick() {
        return wxNick;
    }

    public void setWxNick(String wxNick) {
        this.wxNick = wxNick;
    }

    public String getCountIntegral() {
        return countIntegral;
    }

    public void setCountIntegral(String countIntegral) {
        this.countIntegral = countIntegral;
    }

    public String getLevelName() {
        return levelName;
    }

    public void setLevelName(String levelName) {
        this.levelName = levelName;
    }

    public Long getLevelId() {
        return levelId;
    }

    public void setLevelId(Long levelId) {
        this.levelId = levelId;
    }

    public String getBarCode() {
        return barCode;
    }

    public void setBarCode(String barCode) {
        this.barCode = barCode;
    }

    public String getCardNo() {
        return cardNo;
    }

    public void setCardNo(String cardNo) {
        this.cardNo = cardNo;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public String getMemberDiscount() {
        return memberDiscount;
    }

    public void setMemberDiscount(String memberDiscount) {
        this.memberDiscount = memberDiscount;
    }

    public String getAdditionalDiscount() {
        return additionalDiscount;
    }

    public void setAdditionalDiscount(String additionalDiscount) {
        this.additionalDiscount = additionalDiscount;
    }

    public String getCardStyle() {
        return cardStyle;
    }

    public void setCardStyle(String cardStyle) {
        this.cardStyle = cardStyle;
    }

    public List<AppletVipPrivilegePO> getAppletVipPrivilegePOList() {
        return appletVipPrivilegePOList;
    }

    public void setAppletVipPrivilegePOList(List<AppletVipPrivilegePO> appletVipPrivilegePOList) {
        this.appletVipPrivilegePOList = appletVipPrivilegePOList;
    }

    public String getInstructions() {
        return instructions;
    }

    public void setInstructions(String instructions) {
        this.instructions = instructions;
    }

    public Boolean getImg() {
        return isImg;
    }

    public void setImg(Boolean img) {
        isImg = img;
    }

    public Integer getDiscountMethod() {
        return discountMethod;
    }

    public void setDiscountMethod(Integer discountMethod) {
        this.discountMethod = discountMethod;
    }

    public BigDecimal getMbrConsumeAllMoney() {
        return mbrConsumeAllMoney;
    }

    public void setMbrConsumeAllMoney(BigDecimal mbrConsumeAllMoney) {
        this.mbrConsumeAllMoney = mbrConsumeAllMoney;
    }
}
